http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
index 9ac37ff..628a5e1 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
@@ -150,9 +150,9 @@ public interface ComputeTaskSession {
      * job siblings will be requested from task node for each apply.
      *
      * @return Collection of grid job siblings executing within this task.
-     * @throws IgniteCheckedException If job siblings can not be received from 
task node.
+     * @throws IgniteException If job siblings can not be received from task 
node.
      */
-    public Collection<ComputeJobSibling> getJobSiblings() throws 
IgniteCheckedException;
+    public Collection<ComputeJobSibling> getJobSiblings() throws 
IgniteException;
 
     /**
      * Refreshes collection of job siblings. This method has no effect when 
invoked
@@ -162,9 +162,9 @@ public interface ComputeTaskSession {
      * will re-request list of siblings from originating node.
      *
      * @return Refreshed collection of job siblings.
-     * @throws IgniteCheckedException If refresh failed.
+     * @throws IgniteException If refresh failed.
      */
-    public Collection<ComputeJobSibling> refreshJobSiblings() throws 
IgniteCheckedException;
+    public Collection<ComputeJobSibling> refreshJobSiblings() throws 
IgniteException;
 
     /**
      * Gets job sibling for a given ID.
@@ -175,9 +175,9 @@ public interface ComputeTaskSession {
      *
      * @param jobId Job ID to get the sibling for.
      * @return Grid job sibling for a given ID.
-     * @throws IgniteCheckedException If job sibling can not be received from 
task node.
+     * @throws IgniteException If job sibling can not be received from task 
node.
      */
-    @Nullable public ComputeJobSibling getJobSibling(IgniteUuid jobId) throws 
IgniteCheckedException;
+    @Nullable public ComputeJobSibling getJobSibling(IgniteUuid jobId) throws 
IgniteException;
 
     /**
      * Sets session attributed. Note that task session is distributed and
@@ -190,9 +190,9 @@ public interface ComputeTaskSession {
      *
      * @param key Attribute key.
      * @param val Attribute value. Can be {@code null}.
-     * @throws IgniteCheckedException If sending of attribute message failed.
+     * @throws IgniteException If sending of attribute message failed.
      */
-    public void setAttribute(Object key, @Nullable Object val) throws 
IgniteCheckedException;
+    public void setAttribute(Object key, @Nullable Object val) throws 
IgniteException;
 
     /**
      * Gets an attribute set by {@link #setAttribute(Object, Object)} or 
{@link #setAttributes(Map)}
@@ -217,9 +217,9 @@ public interface ComputeTaskSession {
      * This method is no-op if the session has finished.
      *
      * @param attrs Attributes to set.
-     * @throws IgniteCheckedException If sending of attribute message failed.
+     * @throws IgniteException If sending of attribute message failed.
      */
-    public void setAttributes(Map<?, ?> attrs) throws IgniteCheckedException;
+    public void setAttributes(Map<?, ?> attrs) throws IgniteException;
 
     /**
      * Gets all attributes.
@@ -315,12 +315,12 @@ public interface ComputeTaskSession {
      *
      * @param key Key to be used to load this checkpoint in future.
      * @param state Intermediate job state to save.
-     * @throws IgniteCheckedException If failed to save intermediate job state.
+     * @throws IgniteException If failed to save intermediate job state.
      * @see #loadCheckpoint(String)
      * @see #removeCheckpoint(String)
      * @see org.apache.ignite.spi.checkpoint.CheckpointSpi
      */
-    public void saveCheckpoint(String key, Object state) throws 
IgniteCheckedException;
+    public void saveCheckpoint(String key, Object state) throws 
IgniteException;
 
     /**
      * Saves intermediate state of a job to a storage. The storage 
implementation is defined
@@ -344,13 +344,13 @@ public interface ComputeTaskSession {
      *      timeout expires.
      * @param timeout Maximum time this state should be kept by the underlying 
storage. Value {@code 0} means that
      *       timeout will never expire.
-     * @throws IgniteCheckedException If failed to save intermediate job state.
+     * @throws IgniteException If failed to save intermediate job state.
      * @see #loadCheckpoint(String)
      * @see #removeCheckpoint(String)
      * @see org.apache.ignite.spi.checkpoint.CheckpointSpi
      */
     public void saveCheckpoint(String key, Object state, 
ComputeTaskSessionScope scope, long timeout)
-        throws IgniteCheckedException;
+        throws IgniteException;
 
     /**
      * Saves intermediate state of a job or task to a storage. The storage 
implementation is defined
@@ -375,13 +375,13 @@ public interface ComputeTaskSession {
      * @param timeout Maximum time this state should be kept by the underlying 
storage. Value <tt>0</tt> means that
      *      timeout will never expire.
      * @param overwrite Whether or not overwrite checkpoint if it already 
exists.
-     * @throws IgniteCheckedException If failed to save intermediate job state.
+     * @throws IgniteException If failed to save intermediate job state.
      * @see #loadCheckpoint(String)
      * @see #removeCheckpoint(String)
      * @see org.apache.ignite.spi.checkpoint.CheckpointSpi
      */
     public void saveCheckpoint(String key, Object state, 
ComputeTaskSessionScope scope, long timeout,
-        boolean overwrite) throws IgniteCheckedException;
+        boolean overwrite) throws IgniteException;
 
     /**
      * Loads job's state previously saved via {@link #saveCheckpoint(String, 
Object, ComputeTaskSessionScope, long)}
@@ -396,11 +396,11 @@ public interface ComputeTaskSession {
      * @param key Key for intermediate job state to load.
      * @param <T> Type of the checkpoint state.
      * @return Previously saved state or {@code null} if no state was found 
for a given {@code key}.
-     * @throws IgniteCheckedException If failed to load job state.
+     * @throws IgniteException If failed to load job state.
      * @see #removeCheckpoint(String)
      * @see org.apache.ignite.spi.checkpoint.CheckpointSpi
      */
-    @Nullable public <T> T loadCheckpoint(String key) throws 
IgniteCheckedException;
+    @Nullable public <T> T loadCheckpoint(String key) throws IgniteException;
 
     /**
      * Removes previously saved job's state for a given {@code key} from an 
underlying storage.
@@ -412,11 +412,11 @@ public interface ComputeTaskSession {
      *
      * @param key Key for intermediate job state to load.
      * @return {@code true} if job state was removed, {@code false} if state 
was not found.
-     * @throws IgniteCheckedException If failed to remove job state.
+     * @throws IgniteException If failed to remove job state.
      * @see #loadCheckpoint(String)
      * @see org.apache.ignite.spi.checkpoint.CheckpointSpi
      */
-    public boolean removeCheckpoint(String key) throws IgniteCheckedException;
+    public boolean removeCheckpoint(String key) throws IgniteException;
 
     /**
      * Gets a collection of grid nodes IDs.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSplitAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSplitAdapter.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSplitAdapter.java
index ab80844..fd35d70 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSplitAdapter.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSplitAdapter.java
@@ -27,7 +27,7 @@ import java.util.*;
  * <pre name="code" class="java">
  * public class MyFooBarTask extends GridComputeTaskSplitAdapter&lt;Object, 
String&gt; {
  *     &#64;Override
- *     protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, 
Object arg) throws IgniteCheckedException {
+ *     protected Collection&lt;? extends ComputeJob&gt; split(int gridSize, 
Object arg) throws IgniteException {
  *         List&lt;MyFooBarJob&gt; jobs = new 
ArrayList&lt;MyFooBarJob&gt;(gridSize);
  *
  *         for (int i = 0; i &lt; gridSize; i++) {
@@ -40,7 +40,7 @@ import java.util.*;
  *     }
  *
  *     // Aggregate results into one compound result.
- *     public String reduce(List&lt;GridComputeJobResult&gt; results) throws 
IgniteCheckedException {
+ *     public String reduce(List&lt;GridComputeJobResult&gt; results) throws 
IgniteException {
  *         // For the purpose of this example we simply
  *         // concatenate string representation of every
  *         // job result
@@ -83,22 +83,22 @@ public abstract class ComputeTaskSplitAdapter<T, R> extends 
ComputeTaskAdapter<T
      *      available grid nodes. Note that if number of jobs is greater than 
number of
      *      grid nodes (i.e, grid size), the grid nodes will be reused and 
some jobs
      *      will end up on the same grid nodes.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      *
      * @see ComputeTask#map(List, Object)
      */
-    protected abstract Collection<? extends ComputeJob> split(int gridSize, T 
arg) throws IgniteCheckedException;
+    protected abstract Collection<? extends ComputeJob> split(int gridSize, T 
arg) throws IgniteException;
 
     /** {@inheritDoc} */
     @Override public final Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, T arg)
-        throws IgniteCheckedException {
+        throws IgniteException {
         assert subgrid != null;
         assert !subgrid.isEmpty();
 
         Collection<? extends ComputeJob> jobs = split(subgrid.size(), arg);
 
         if (F.isEmpty(jobs))
-            throw new IgniteCheckedException("Split returned no jobs.");
+            throw new IgniteException("Split returned no jobs.");
 
         Map<ComputeJob, ClusterNode> map = U.newHashMap(jobs.size());
 
@@ -106,7 +106,7 @@ public abstract class ComputeTaskSplitAdapter<T, R> extends 
ComputeTaskAdapter<T
             ClusterNode old = map.put(job, balancer.getBalancedNode(job, 
null));
 
             if (old != null)
-                throw new IgniteCheckedException("Failed to map task (same job 
instance is being mapped more than once) " +
+                throw new IgniteException("Failed to map task (same job 
instance is being mapped more than once) " +
                     "[job=" + job + ", task=" + this + ']');
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
index e2690be..4e304dd 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
@@ -16,7 +16,7 @@ import org.jetbrains.annotations.*;
  * This exception indicates that task execution timed out. It is thrown from
  * {@link ComputeTaskFuture#get()} method.
  */
-public class ComputeTaskTimeoutException extends IgniteCheckedException {
+public class ComputeTaskTimeoutException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/ComputeUserUndeclaredException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeUserUndeclaredException.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeUserUndeclaredException.java
index bec56d2..a2c2e06 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeUserUndeclaredException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeUserUndeclaredException.java
@@ -17,7 +17,7 @@ import org.jetbrains.annotations.*;
  * assumed the code in grid task, grid job or SPI. In most cases it should be 
an indication of unrecoverable
  * error condition such as assertion, {@link NullPointerException}, {@link 
OutOfMemoryError}, etc.
  */
-public class ComputeUserUndeclaredException extends IgniteCheckedException {
+public class ComputeUserUndeclaredException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
index 86e4344..8e72036 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/gridify/Gridify.java
@@ -83,7 +83,7 @@ import java.lang.annotation.*;
  *        }));
  *    }
  *
- *    public Integer reduce(List&lt;GridComputeJobResult&gt; results) throws 
IgniteCheckedException {
+ *    public Integer reduce(List&lt;GridComputeJobResult&gt; results) throws 
IgniteException {
  *        return results.size() - 1 + 
F.sum(F.&lt;Integer&gt;jobResults(results));
  *    }
  * }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifyInterceptor.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifyInterceptor.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifyInterceptor.java
index 09832bb..7de0ffb 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifyInterceptor.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/GridifyInterceptor.java
@@ -28,7 +28,7 @@ public interface GridifyInterceptor {
      * @param gridify Gridify annotation instance that caused the 
grid-enabling.
      * @param arg Gridify argument.
      * @return {@code True} if method should be grid-enabled, {@code false} 
otherwise.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public boolean isGridify(Annotation gridify, GridifyArgument arg) throws 
IgniteCheckedException;
+    public boolean isGridify(Annotation gridify, GridifyArgument arg) throws 
IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultRangeTask.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultRangeTask.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultRangeTask.java
index 13c73bc..a6451d9 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultRangeTask.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultRangeTask.java
@@ -104,13 +104,13 @@ public class GridifyDefaultRangeTask extends 
ComputeTaskAdapter<GridifyRangeArgu
 
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, GridifyRangeArgument arg)
-        throws IgniteCheckedException {
+        throws IgniteException {
         assert !subgrid.isEmpty() : "Subgrid should not be empty: " + subgrid;
 
         assert ignite != null : "Grid instance could not be injected";
 
         if (splitSize < threshold && splitSize != 0 && threshold != 0) {
-            throw new IgniteCheckedException("Incorrect Gridify annotation 
parameters. Value for parameter " +
+            throw new IgniteException("Incorrect Gridify annotation 
parameters. Value for parameter " +
                 "'splitSize' should not be less than parameter 'threshold' 
[splitSize=" + splitSize +
                 ", threshold=" + threshold + ']');
         }
@@ -125,7 +125,7 @@ public class GridifyDefaultRangeTask extends 
ComputeTaskAdapter<GridifyRangeArgu
             }
 
             if (exclNodes.size() == subgrid.size())
-                throw new IgniteCheckedException("Failed to execute on grid 
where all nodes excluded.");
+                throw new IgniteException("Failed to execute on grid where all 
nodes excluded.");
         }
 
         int inputPerNode = splitSize;
@@ -176,7 +176,7 @@ public class GridifyDefaultRangeTask extends 
ComputeTaskAdapter<GridifyRangeArgu
     }
 
     /** {@inheritDoc} */
-    @Override public final Collection<?> reduce(List<ComputeJobResult> 
results) throws IgniteCheckedException {
+    @Override public final Collection<?> reduce(List<ComputeJobResult> 
results) throws IgniteException {
         assert results.size() >= 1;
 
         Collection<Object> data = new ArrayList<>(results.size());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
index 6deb188..0f04a6b 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/gridify/aop/GridifyDefaultTask.java
@@ -72,7 +72,7 @@ public class GridifyDefaultTask extends 
ComputeTaskAdapter<GridifyArgument, Obje
     }
 
     /** {@inheritDoc} */
-    @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, GridifyArgument arg) throws 
IgniteCheckedException {
+    @Override public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, GridifyArgument arg) throws IgniteException {
         assert !subgrid.isEmpty() : "Subgrid should not be empty: " + subgrid;
 
         assert ignite != null : "Grid instance could not be injected";
@@ -91,7 +91,7 @@ public class GridifyDefaultTask extends 
ComputeTaskAdapter<GridifyArgument, Obje
     }
 
     /** {@inheritDoc} */
-    @Override public final Object reduce(List<ComputeJobResult> results) 
throws IgniteCheckedException {
+    @Override public final Object reduce(List<ComputeJobResult> results) 
throws IgniteException {
         assert results.size() == 1;
 
         ComputeJobResult res = results.get(0);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
 
b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
index 3545a27..16ffea9 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/configuration/IgniteAddressResolver.java
@@ -29,7 +29,7 @@ public interface IgniteAddressResolver {
      *      Note that if there are more than one external network the local 
address
      *      can be mapped differently to each and therefore may need to return
      *      multiple external addresses.
-     * @throws IgniteCheckedException Thrown if any exception occurs.
+     * @throws IgniteException Thrown if any exception occurs.
      */
-    public Collection<InetSocketAddress> 
getExternalAddresses(InetSocketAddress addr) throws IgniteCheckedException;
+    public Collection<InetSocketAddress> 
getExternalAddresses(InetSocketAddress addr) throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java 
b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
index 0164d86..dbd724b 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsException.java
@@ -15,7 +15,7 @@ import org.jetbrains.annotations.*;
 /**
  * {@code GGFS} exception thrown by file system components.
  */
-public class IgniteFsException extends IgniteCheckedException {
+public class IgniteFsException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
index 079891a..df3a33c 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
@@ -26,7 +26,7 @@ import java.io.*;
 public abstract class IgniteFsInputStreamJobAdapter extends IgniteFsJobAdapter 
{
     /** {@inheritDoc} */
     @Override public final Object execute(IgniteFs ggfs, IgniteFsFileRange 
range, IgniteFsInputStream in)
-        throws IgniteCheckedException, IOException {
+        throws IgniteException, IOException {
         in.seek(range.start());
 
         return execute(ggfs, new IgniteFsRangeInputStream(in, range));
@@ -38,8 +38,8 @@ public abstract class IgniteFsInputStreamJobAdapter extends 
IgniteFsJobAdapter {
      * @param ggfs GGFS instance.
      * @param in Input stream.
      * @return Execution result.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      * @throws IOException If IO exception encountered while working with 
stream.
      */
-    public abstract Object execute(IgniteFs ggfs, IgniteFsRangeInputStream in) 
throws IgniteCheckedException, IOException;
+    public abstract Object execute(IgniteFs ggfs, IgniteFsRangeInputStream in) 
throws IgniteException, IOException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
index 8fdc30c..6e37a2d 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
@@ -42,10 +42,10 @@ public interface IgniteFsJob {
      * @param in Input stream for split file. This input stream is not aligned 
to range and points to file start
      *     by default.
      * @return Execution result.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      * @throws IOException If file system operation resulted in IO exception.
      */
-    public Object execute(IgniteFs ggfs, IgniteFsFileRange range, 
IgniteFsInputStream in) throws IgniteCheckedException,
+    public Object execute(IgniteFs ggfs, IgniteFsFileRange range, 
IgniteFsInputStream in) throws IgniteException,
         IOException;
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java 
b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
index ccca6ba..4fb0b52 100644
--- a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
+++ b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
@@ -98,7 +98,7 @@ public interface LifecycleBean {
      * This method is called when lifecycle event occurs.
      *
      * @param evt Lifecycle event.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public void onLifecycleEvent(LifecycleEventType evt) throws 
IgniteCheckedException;
+    public void onLifecycleEvent(LifecycleEventType evt) throws 
IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
 
b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
index 7a5e91f..baecc2a 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteAbstractMarshaller.java
@@ -26,7 +26,7 @@ public abstract class IgniteAbstractMarshaller implements 
IgniteMarshaller {
     public static final int DFLT_BUFFER_SIZE = 512;
 
     /** {@inheritDoc} */
-    @Override public byte[] marshal(@Nullable Object obj) throws 
IgniteCheckedException {
+    @Override public byte[] marshal(@Nullable Object obj) throws 
IgniteException {
         GridByteArrayOutputStream out = null;
 
         try {
@@ -42,7 +42,7 @@ public abstract class IgniteAbstractMarshaller implements 
IgniteMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) 
throws IgniteCheckedException {
+    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) 
throws IgniteException {
         GridByteArrayInputStream in = null;
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java 
b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
index 5fd97af..5ca30d1 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/marshaller/IgniteMarshaller.java
@@ -90,18 +90,18 @@ public interface IgniteMarshaller {
      *
      * @param obj Object to marshal.
      * @param out Output stream to marshal into.
-     * @throws IgniteCheckedException If marshalling failed.
+     * @throws IgniteException If marshalling failed.
      */
-    public void marshal(@Nullable Object obj, OutputStream out) throws 
IgniteCheckedException;
+    public void marshal(@Nullable Object obj, OutputStream out) throws 
IgniteException;
 
     /**
      * Marshals object to byte array.
      *
      * @param obj Object to marshal.
      * @return Byte array.
-     * @throws IgniteCheckedException If marshalling failed.
+     * @throws IgniteException If marshalling failed.
      */
-    public byte[] marshal(@Nullable Object obj) throws IgniteCheckedException;
+    public byte[] marshal(@Nullable Object obj) throws IgniteException;
 
     /**
      * Unmarshals object from the output stream using given class loader.
@@ -111,9 +111,9 @@ public interface IgniteMarshaller {
      * @param in Input stream.
      * @param clsLdr Class loader to use.
      * @return Unmarshalled object.
-     * @throws IgniteCheckedException If unmarshalling failed.
+     * @throws IgniteException If unmarshalling failed.
      */
-    public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) 
throws IgniteCheckedException;
+    public <T> T unmarshal(InputStream in, @Nullable ClassLoader clsLdr) 
throws IgniteException;
 
     /**
      * Unmarshals object from byte array using given class loader.
@@ -122,7 +122,7 @@ public interface IgniteMarshaller {
      * @param arr Byte array.
      * @param clsLdr Class loader to use.
      * @return Unmarshalled object.
-     * @throws IgniteCheckedException If unmarshalling failed.
+     * @throws IgniteException If unmarshalling failed.
      */
-    public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws 
IgniteCheckedException;
+    public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) throws 
IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
 
b/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
index 1853ee7..e358252 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/marshaller/jdk/IgniteJdkMarshaller.java
@@ -78,7 +78,7 @@ import java.io.*;
  */
 public class IgniteJdkMarshaller extends IgniteAbstractMarshaller {
     /** {@inheritDoc} */
-    @Override public void marshal(@Nullable Object obj, OutputStream out) 
throws IgniteCheckedException {
+    @Override public void marshal(@Nullable Object obj, OutputStream out) 
throws IgniteException {
         assert out != null;
 
         ObjectOutputStream objOut = null;
@@ -92,7 +92,7 @@ public class IgniteJdkMarshaller extends 
IgniteAbstractMarshaller {
             objOut.flush();
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to serialize object: " + 
obj, e);
+            throw new IgniteException("Failed to serialize object: " + obj, e);
         }
         finally{
             U.closeQuiet(objOut);
@@ -101,7 +101,7 @@ public class IgniteJdkMarshaller extends 
IgniteAbstractMarshaller {
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked"})
-    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader 
clsLdr) throws IgniteCheckedException {
+    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader 
clsLdr) throws IgniteException {
         assert in != null;
 
         if (clsLdr == null)
@@ -115,10 +115,10 @@ public class IgniteJdkMarshaller extends 
IgniteAbstractMarshaller {
             return (T)objIn.readObject();
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to deserialize object 
with given class loader: " + clsLdr, e);
+            throw new IgniteException("Failed to deserialize object with given 
class loader: " + clsLdr, e);
         }
         catch (ClassNotFoundException e) {
-            throw new IgniteCheckedException("Failed to find class with given 
class loader for unmarshalling " +
+            throw new IgniteException("Failed to find class with given class 
loader for unmarshalling " +
                 "(make sure same versions of all classes are available on all 
nodes or enable peer-class-loading): " +
                 clsLdr, e);
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
 
b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
index d42954a..e846e10 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/marshaller/optimized/IgniteOptimizedMarshaller.java
@@ -136,11 +136,11 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
      * @param clsNames User preregistered class names.
      * @param clsNamesPath Path to a file with user preregistered class names.
      * @param poolSize Object streams pool size.
-     * @throws IgniteCheckedException If an I/O error occurs while writing 
stream header.
+     * @throws IgniteException If an I/O error occurs while writing stream 
header.
      * @throws IgniteException If this marshaller is not supported on the 
current JVM.
      */
     public IgniteOptimizedMarshaller(boolean requireSer, @Nullable 
List<String> clsNames,
-                                     @Nullable String clsNamesPath, int 
poolSize) throws IgniteCheckedException {
+                                     @Nullable String clsNamesPath, int 
poolSize) throws IgniteException {
         this(requireSer);
 
         setClassNames(clsNames);
@@ -192,16 +192,16 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
      * <b>NOTE</b>: this class list must be identical on all nodes and in the 
same order.
      *
      * @param path Path to a file with user preregistered class names.
-     * @throws IgniteCheckedException If an error occurs while writing stream 
header.
+     * @throws IgniteException If an error occurs while writing stream header.
      */
-    public void setClassNamesPath(@Nullable String path) throws 
IgniteCheckedException {
+    public void setClassNamesPath(@Nullable String path) throws 
IgniteException {
         if (path == null)
             return;
 
         URL url = GridUtils.resolveGridGainUrl(path, false);
 
         if (url == null)
-            throw new IgniteCheckedException("Failed to find resource for 
name: " + path);
+            throw new IgniteException("Failed to find resource for name: " + 
path);
 
         List<String> clsNames;
 
@@ -216,7 +216,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
             }
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to read class names from 
path: " + path, e);
+            throw new IgniteException("Failed to read class names from path: " 
+ path, e);
         }
 
         setClassNames(clsNames);
@@ -260,7 +260,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public void marshal(@Nullable Object obj, OutputStream out) 
throws IgniteCheckedException {
+    @Override public void marshal(@Nullable Object obj, OutputStream out) 
throws IgniteException {
         assert out != null;
 
         IgniteOptimizedObjectOutputStream objOut = null;
@@ -275,7 +275,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
             objOut.writeObject(obj);
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to serialize object: " + 
obj, e);
+            throw new IgniteException("Failed to serialize object: " + obj, e);
         }
         finally {
             IgniteOptimizedObjectStreamRegistry.closeOut(objOut);
@@ -283,7 +283,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public byte[] marshal(@Nullable Object obj) throws 
IgniteCheckedException {
+    @Override public byte[] marshal(@Nullable Object obj) throws 
IgniteException {
         IgniteOptimizedObjectOutputStream objOut = null;
 
         try {
@@ -296,7 +296,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
             return objOut.out().array();
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to serialize object: " + 
obj, e);
+            throw new IgniteException("Failed to serialize object: " + obj, e);
         }
         finally {
             IgniteOptimizedObjectStreamRegistry.closeOut(objOut);
@@ -304,7 +304,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader 
clsLdr) throws IgniteCheckedException {
+    @Override public <T> T unmarshal(InputStream in, @Nullable ClassLoader 
clsLdr) throws IgniteException {
         assert in != null;
 
         IgniteOptimizedObjectInputStream objIn = null;
@@ -319,10 +319,10 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
             return (T)objIn.readObject();
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to deserialize object 
with given class loader: " + clsLdr, e);
+            throw new IgniteException("Failed to deserialize object with given 
class loader: " + clsLdr, e);
         }
         catch (ClassNotFoundException e) {
-            throw new IgniteCheckedException("Failed to find class with given 
class loader for unmarshalling " +
+            throw new IgniteException("Failed to find class with given class 
loader for unmarshalling " +
                 "(make sure same versions of all classes are available on all 
nodes or enable peer-class-loading): " +
                 clsLdr, e);
         }
@@ -332,7 +332,7 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) 
throws IgniteCheckedException {
+    @Override public <T> T unmarshal(byte[] arr, @Nullable ClassLoader clsLdr) 
throws IgniteException {
         assert arr != null;
 
         IgniteOptimizedObjectInputStream objIn = null;
@@ -347,10 +347,10 @@ public class IgniteOptimizedMarshaller extends 
IgniteAbstractMarshaller {
             return (T)objIn.readObject();
         }
         catch (IOException e) {
-            throw new IgniteCheckedException("Failed to deserialize object 
with given class loader: " + clsLdr, e);
+            throw new IgniteException("Failed to deserialize object with given 
class loader: " + clsLdr, e);
         }
         catch (ClassNotFoundException e) {
-            throw new IgniteCheckedException("Failed to find class with given 
class loader for unmarshalling " +
+            throw new IgniteException("Failed to find class with given class 
loader for unmarshalling " +
                 "(make sure same version of all classes are available on all 
nodes or enable peer-class-loading): " +
                 clsLdr, e);
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java 
b/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
index 33280dc..4888269 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/PluginProvider.java
@@ -57,26 +57,26 @@ public interface PluginProvider<C extends 
PluginConfiguration> {
      *
      * @param ctx Plugin context.
      * @param attrs Attributes.
-     * @throws IgniteCheckedException Throws in case of any errors.
+     * @throws IgniteException Throws in case of any errors.
      */
-    public void start(PluginContext ctx, Map<String, Object> attrs) throws 
IgniteCheckedException;
+    public void start(PluginContext ctx, Map<String, Object> attrs);
 
     /**
      * Stops grid component.
      *
      * @param cancel If {@code true}, then all ongoing tasks or jobs for 
relevant
      *      components need to be cancelled.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public void stop(boolean cancel) throws IgniteCheckedException;
+    public void stop(boolean cancel);
 
     /**
      * Callback that notifies that Ignite has successfully started,
      * including all internal components.
      *
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public void onIgniteStart() throws IgniteCheckedException;
+    public void onIgniteStart();
 
     /**
      * Callback to notify that Ignite is about to stop.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
 
b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
index eba4cae..cf7e6b3 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurity.java
@@ -77,7 +77,7 @@ public interface GridSecurity {
      *
      * @return Collection of authenticated subjects.
      */
-    public Collection<GridSecuritySubject> authenticatedSubjects() throws 
IgniteCheckedException;
+    public Collection<GridSecuritySubject> authenticatedSubjects() throws 
IgniteException;
 
     /**
      * Gets security subject based on subject ID.
@@ -85,5 +85,5 @@ public interface GridSecurity {
      * @param subjId Subject ID.
      * @return Authorized security subject.
      */
-    public GridSecuritySubject authenticatedSubject(UUID subjId) throws 
IgniteCheckedException;
+    public GridSecuritySubject authenticatedSubject(UUID subjId) throws 
IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
 
b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
index 0cabf26..6aff89d 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsBasicProvider.java
@@ -30,7 +30,7 @@ public class GridSecurityCredentialsBasicProvider implements 
GridSecurityCredent
     }
 
     /** {@inheritDoc} */
-    @Override public GridSecurityCredentials credentials() throws 
IgniteCheckedException {
+    @Override public GridSecurityCredentials credentials() throws 
IgniteException {
         return cred;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
 
b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
index b5d8d4e..ab66a35 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/plugin/security/GridSecurityCredentialsProvider.java
@@ -35,7 +35,7 @@ public interface GridSecurityCredentialsProvider {
      * Gets security credentials.
      *
      * @return Security credentials.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
-    public GridSecurityCredentials credentials() throws IgniteCheckedException;
+    public GridSecurityCredentials credentials() throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
 
b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
index 785fde2..e40e81f 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/plugin/segmentation/GridSegmentationResolver.java
@@ -50,7 +50,7 @@ public interface GridSegmentationResolver extends 
Serializable {
      * in configuration.
      *
      * @return {@code True} if segment is correct, {@code false} otherwise.
-     * @throws IgniteCheckedException If an error occurred.
+     * @throws IgniteException If an error occurred.
      */
-    public abstract boolean isValidSegment() throws IgniteCheckedException;
+    public abstract boolean isValidSegment() throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
 
b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
index de09649..36c4693 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductLicenseException.java
@@ -16,7 +16,7 @@ import org.jetbrains.annotations.*;
 /**
  * This exception is thrown when license violation is detected.
  */
-public class IgniteProductLicenseException extends IgniteCheckedException {
+public class IgniteProductLicenseException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
 
b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
index 540b3e9..27adaef 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/product/IgniteProductVersion.java
@@ -273,7 +273,7 @@ public class IgniteProductVersion implements 
Comparable<IgniteProductVersion>, E
 
                 return new IgniteProductVersion(major, minor, maintenance, 
stage, revTs, revHash);
             }
-            catch (IllegalStateException | IndexOutOfBoundsException | 
NumberFormatException | IgniteCheckedException e) {
+            catch (IllegalStateException | IndexOutOfBoundsException | 
NumberFormatException | IgniteException e) {
                 throw new IllegalStateException("Failed to parse version: " + 
verStr, e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java 
b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
index f9756b2..34573a1 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/scheduler/SchedulerFuture.java
@@ -84,9 +84,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> {
      * @param cnt Array length.
      * @param start Start timestamp.
      * @return Array of the next execution times in milliseconds.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public long[] nextExecutionTimes(int cnt, long start) throws 
IgniteCheckedException;
+    public long[] nextExecutionTimes(int cnt, long start) throws 
IgniteException;
 
     /**
      * Gets total count of executions this task has already completed.
@@ -106,9 +106,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> 
{
      * Gets next execution time of scheduled task.
      *
      * @return Next execution time in milliseconds.
-     * @throws IgniteCheckedException Thrown in case of any errors.
+     * @throws IgniteException Thrown in case of any errors.
      */
-    public long nextExecutionTime() throws IgniteCheckedException;
+    public long nextExecutionTime() throws IgniteException;
 
     /**
      * Gets result of the last execution of scheduled task, or
@@ -117,9 +117,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> 
{
      *
      * @return Result of the last execution, or {@code null} if
      *      there isn't one yet.
-     * @throws IgniteCheckedException If last execution resulted in exception.
+     * @throws IgniteException If last execution resulted in exception.
      */
-    public R last() throws IgniteCheckedException;
+    public R last() throws IgniteException;
 
     /**
      * Waits for the completion of the next scheduled execution and returns 
its result.
@@ -127,9 +127,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> 
{
      * @return Result of the next execution.
      * @throws CancellationException {@inheritDoc}
      * @throws GridInterruptedException {@inheritDoc}
-     * @throws IgniteCheckedException {@inheritDoc}
+     * @throws IgniteException {@inheritDoc}
      */
-    @Override public R get() throws IgniteCheckedException;
+    @Override public R get() throws IgniteException;
 
     /**
      * Waits for the completion of the next scheduled execution for
@@ -141,9 +141,9 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> 
{
      * @throws CancellationException {@inheritDoc}
      * @throws GridInterruptedException {@inheritDoc}
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException 
{@inheritDoc}
-     * @throws IgniteCheckedException {@inheritDoc}
+     * @throws IgniteException {@inheritDoc}
      */
-    @Override public R get(long timeout) throws IgniteCheckedException;
+    @Override public R get(long timeout) throws IgniteException;
 
     /**
      * Waits for the completion of the next scheduled execution for
@@ -155,7 +155,7 @@ public interface SchedulerFuture<R> extends IgniteFuture<R> 
{
      * @throws CancellationException {@inheritDoc}
      * @throws GridInterruptedException {@inheritDoc}
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException 
{@inheritDoc}
-     * @throws IgniteCheckedException {@inheritDoc}
+     * @throws IgniteException {@inheritDoc}
      */
-    @Override public R get(long timeout, TimeUnit unit) throws 
IgniteCheckedException;
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
index 901b232..4289800 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiCloseableIterator.java
@@ -25,7 +25,7 @@ public interface IgniteSpiCloseableIterator<T> extends 
Iterator<T>, AutoCloseabl
      * The method is invoked automatically on objects managed by the
      * {@code try-with-resources} statement.
      *
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
-    @Override public void close() throws IgniteCheckedException;
+    @Override public void close() throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java 
b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
index 51fbf2b..3064bbe 100644
--- a/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/IgniteSpiException.java
@@ -14,7 +14,7 @@ import org.apache.ignite.*;
 /**
  * Exception thrown by SPI implementations.
  */
-public class IgniteSpiException extends IgniteCheckedException {
+public class IgniteSpiException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java 
b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
index cd94d7d..c54938d 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/IgniteFsFileSystem.java
@@ -40,9 +40,9 @@ public interface IgniteFsFileSystem {
      *
      * @param path Path to check for existence in the file system.
      * @return {@code True} if such file exists, otherwise - {@code false}.
      * @throws IgniteCheckedException In case of error.
      */
-    public boolean exists(IgniteFsPath path) throws IgniteCheckedException;
+    public boolean exists(IgniteFsPath path) throws IgniteException;
 
     /**
      * Updates file information for the specified path. Existent properties, 
not listed in the passed collection,
@@ -60,9 +60,9 @@ public interface IgniteFsFileSystem {
      * @param path File path to set properties for.
      * @param props Properties to update.
      * @return File information for specified path or {@code null} if such 
path does not exist.
      * @throws IgniteCheckedException In case of error.
      */
-    @Nullable public IgniteFsFile update(IgniteFsPath path, Map<String, 
String> props) throws IgniteCheckedException;
+    @Nullable public IgniteFsFile update(IgniteFsPath path, Map<String, 
String> props) throws IgniteException;
 
     /**
      * Renames/moves a file.
@@ -80,10 +80,10 @@ public interface IgniteFsFileSystem {
      * @param src Source file path to rename.
      * @param dest Destination file path. If destination path is a directory, 
then source file will be placed
      *     into destination directory with original name.
      * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If source file doesn't exist.
      */
-    public void rename(IgniteFsPath src, IgniteFsPath dest) throws 
IgniteCheckedException;
+    public void rename(IgniteFsPath src, IgniteFsPath dest) throws 
IgniteException;
 
     /**
      * Deletes file.
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path File path to delete.
      * @param recursive Delete non-empty directories recursively.
      * @return {@code True} in case of success, {@code false} otherwise.
      * @throws IgniteCheckedException In case of error.
      */
-    boolean delete(IgniteFsPath path, boolean recursive) throws 
IgniteCheckedException;
+    boolean delete(IgniteFsPath path, boolean recursive) throws 
IgniteException;
 
     /**
      * Creates directories under specified path.
      *
      * @param path Path of directories chain to create.
      * @throws IgniteCheckedException In case of error.
      */
-    public void mkdirs(IgniteFsPath path) throws IgniteCheckedException;
+    public void mkdirs(IgniteFsPath path) throws IgniteException;
 
     /**
      * Creates directories under specified path with the specified properties.
      *
      * @param path Path of directories chain to create.
      * @param props Metadata properties to set on created directories.
      * @throws IgniteCheckedException In case of error.
      */
-    public void mkdirs(IgniteFsPath path, @Nullable Map<String, String> props) 
throws IgniteCheckedException;
+    public void mkdirs(IgniteFsPath path, @Nullable Map<String, String> props) 
throws IgniteException;
 
     /**
      * Lists file paths under the specified path.
      *
      * @param path Path to list files under.
      * @return List of files under the specified path.
      * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
-    public Collection<IgniteFsPath> listPaths(IgniteFsPath path) throws 
IgniteCheckedException;
+    public Collection<IgniteFsPath> listPaths(IgniteFsPath path) throws 
IgniteException;
 
     /**
      * Lists files under the specified path.
      *
      * @param path Path to list files under.
      * @return List of files under the specified path.
      * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
-    public Collection<IgniteFsFile> listFiles(IgniteFsPath path) throws 
IgniteCheckedException;
+    public Collection<IgniteFsFile> listFiles(IgniteFsPath path) throws 
IgniteException;
 
     /**
      * Opens a file for reading.
@@ -138,10 +138,10 @@ public interface IgniteFsFileSystem {
      * @param path File path to read.
      * @param bufSize Read buffer size (bytes) or {@code zero} to use default 
value.
      * @return File input stream to read data from.
      * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
-    public IgniteFsReader open(IgniteFsPath path, int bufSize) throws 
IgniteCheckedException;
+    public IgniteFsReader open(IgniteFsPath path, int bufSize) throws 
IgniteException;
 
     /**
      * Creates a file and opens it for writing.
@@ -149,9 +149,9 @@ public interface IgniteFsFileSystem {
      * @param path File path to create.
      * @param overwrite Overwrite file if it already exists. Note: you cannot 
overwrite an existent directory.
      * @return File output stream to write data to.
      * @throws IgniteCheckedException In case of error.
      */
-    public OutputStream create(IgniteFsPath path, boolean overwrite) throws 
IgniteCheckedException;
+    public OutputStream create(IgniteFsPath path, boolean overwrite) throws 
IgniteException;
 
     /**
      * Creates a file and opens it for writing.
@@ -163,10 +163,10 @@ public interface IgniteFsFileSystem {
      * @param blockSize Block size.
      * @param props File properties to set.
      * @return File output stream to write data to.
      * @throws IgniteCheckedException In case of error.
      */
     public OutputStream create(IgniteFsPath path, int bufSize, boolean 
overwrite, int replication, long blockSize,
-       @Nullable Map<String, String> props) throws IgniteCheckedException;
+       @Nullable Map<String, String> props) throws IgniteException;
 
     /**
      * Opens an output stream to an existing file for appending data.
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      * @param create Create file if it doesn't exist yet.
      * @param props File properties to set only in case it file was just 
created.
      * @return File output stream to append data to.
      * @throws IgniteCheckedException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist and create 
flag is {@code false}.
      */
     public OutputStream append(IgniteFsPath path, int bufSize, boolean create, 
@Nullable Map<String, String> props)
-        throws IgniteCheckedException;
+        throws IgniteException;
 
     /**
      * Gets file information for the specified path.
      *
      * @param path Path to get information for.
      * @return File information for specified path or {@code null} if such 
path does not exist.
      * @throws IgniteCheckedException In case of error.
      */
-    @Nullable public IgniteFsFile info(IgniteFsPath path) throws 
IgniteCheckedException;
+    @Nullable public IgniteFsFile info(IgniteFsPath path) throws 
IgniteException;
 
     /**
      * Gets used space in bytes.
      *
      * @return Used space in bytes.
      * @throws IgniteCheckedException In case of error.
      */
-    public long usedSpaceSize() throws IgniteCheckedException;
+    public long usedSpaceSize() throws IgniteException;
 
     /**
      * Gets the implementation specific properties of file system.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsInputStreamJobAdapter.java
----------------------------------------------------------------------
@@ -40,9 +40,9 @@ public interface IgniteFsFileSystem {
      * @param path Path to check for existence in the file system.
      * @return {@code True} if such file exists, otherwise - {@code false}.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -60,9 +60,9 @@ public interface IgniteFsFileSystem {
      * @return File information for specified path or {@code null} if such 
path does not exist.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -80,10 +80,10 @@ public interface IgniteFsFileSystem {
then source file will be placed
      *     into destination directory with original name.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      * @throws IgniteFsFileNotFoundException If source file doesn't exist.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param recursive Delete non-empty directories recursively.
      * @return {@code True} in case of success, {@code false} otherwise.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      *
      * @param path Path of directories chain to create.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path Path of directories chain to create.
      * @param props Metadata properties to set on created directories.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path Path to list files under.
      * @return List of files under the specified path.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
@@ -91,46 +91,46 @@ public interface IgniteFsFileSystem {
      * @param path Path to list files under.
      * @return List of files under the specified path.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
@@ -138,10 +138,10 @@ public interface IgniteFsFileSystem {
value.
      * @return File input stream to read data from.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist.
      */
@@ -149,9 +149,9 @@ public interface IgniteFsFileSystem {
overwrite an existent directory.
      * @return File output stream to write data to.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -163,10 +163,10 @@ public interface IgniteFsFileSystem {
      * @param props File properties to set.
      * @return File output stream to write data to.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
     public OutputStream create(IgniteFsPath path, int bufSize, boolean 
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
created.
      * @return File output stream to append data to.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      * @throws IgniteFsFileNotFoundException If path doesn't exist and create 
flag is {@code false}.
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      * @return File information for specified path or {@code null} if such 
path does not exist.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
@@ -176,28 +176,28 @@ public interface IgniteFsFileSystem {
      *
      * @return Used space in bytes.
-     * @throws IgniteCheckedException In case of error.
+     * @throws IgniteException In case of error.
      */
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
index 0f4fab2..9fcd554 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsRecordResolver.java
@@ -41,9 +41,9 @@ public interface IgniteFsRecordResolver extends Serializable {
      * @param stream Input stream for split file.
      * @param suggestedRecord Suggested file system record.
      * @return New adjusted record. If this method returns {@code null}, 
original record is ignored.
-     * @throws IgniteCheckedException If resolve failed.
+     * @throws IgniteException If resolve failed.
      * @throws IOException If resolve failed.
      */
     @Nullable public IgniteFsFileRange resolveRecords(IgniteFs ggfs, 
IgniteFsInputStream stream,
-        IgniteFsFileRange suggestedRecord) throws IgniteCheckedException, 
IOException;
+        IgniteFsFileRange suggestedRecord) throws IgniteException, IOException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
index e7323d7..808e23c 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsTask.java
@@ -44,14 +44,14 @@ import java.util.*;
  * <pre name="code" class="java">
  * public class WordCountTask extends GridGgfsTask&lt;String, Integer&gt; {
  *     &#64;Override
- *     public GridGgfsJob createJob(GridGgfsPath path, GridGgfsFileRange 
range, GridGgfsTaskArgs&lt;T&gt; args) throws IgniteCheckedException {
+ *     public GridGgfsJob createJob(GridGgfsPath path, GridGgfsFileRange 
range, GridGgfsTaskArgs&lt;T&gt; args) throws IgniteException {
  *         // New job will be created for each range within each file.
  *         // We pass user-provided argument (which is essentially a word to 
look for) to that job.
  *         return new WordCountJob(args.userArgument());
  *     }
  *
  *     // Aggregate results into one compound result.
- *     public Integer reduce(List&lt;GridComputeJobResult&gt; results) throws 
IgniteCheckedException {
+ *     public Integer reduce(List&lt;GridComputeJobResult&gt; results) throws 
IgniteException {
  *         Integer total = 0;
  *
  *         for (GridComputeJobResult res : results) {
@@ -77,7 +77,7 @@ public abstract class IgniteFsTask<T, R> extends 
ComputeTaskAdapter<IgniteFsTask
 
     /** {@inheritDoc} */
     @Nullable @Override public final Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid,
-        @Nullable IgniteFsTaskArgs<T> args) throws IgniteCheckedException {
+        @Nullable IgniteFsTaskArgs<T> args) throws IgniteException {
         assert ignite != null;
         assert args != null;
 
@@ -95,7 +95,7 @@ public abstract class IgniteFsTask<T, R> extends 
ComputeTaskAdapter<IgniteFsTask
                 if (args.skipNonExistentFiles())
                     continue;
                 else
-                    throw new IgniteCheckedException("Failed to process GGFS 
file because it doesn't exist: " + path);
+                    throw new IgniteException("Failed to process GGFS file 
because it doesn't exist: " + path);
             }
 
             Collection<IgniteFsBlockLocation> aff = ggfs.affinity(path, 0, 
file.length(), args.maxRangeLength());
@@ -113,7 +113,7 @@ public abstract class IgniteFsTask<T, R> extends 
ComputeTaskAdapter<IgniteFsTask
                 }
 
                 if (node == null)
-                    throw new IgniteCheckedException("Failed to find any of 
block affinity nodes in subgrid [loc=" + loc +
+                    throw new IgniteException("Failed to find any of block 
affinity nodes in subgrid [loc=" + loc +
                         ", subgrid=" + subgrid + ']');
 
                 IgniteFsJob job = createJob(path, new 
IgniteFsFileRange(file.path(), loc.start(), loc.length()), args);
@@ -143,10 +143,10 @@ public abstract class IgniteFsTask<T, R> extends 
ComputeTaskAdapter<IgniteFsTask
      *      realigned to record boundaries on destination node.
      * @param args Task argument.
      * @return GGFS job. If {@code null} is returned, the passed in file range 
will be skipped.
-     * @throws IgniteCheckedException If job creation failed.
+     * @throws IgniteException If job creation failed.
      */
     @Nullable public abstract IgniteFsJob createJob(IgniteFsPath path, 
IgniteFsFileRange range,
-        IgniteFsTaskArgs<T> args) throws IgniteCheckedException;
+        IgniteFsTaskArgs<T> args) throws IgniteException;
 
     /**
      * Maps list by node ID.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
index cb0257a..5244469 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsByteDelimiterRecordResolver.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.fs.*;
 import org.apache.ignite.fs.mapreduce.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.tostring.*;
@@ -71,7 +70,7 @@ public class IgniteFsByteDelimiterRecordResolver implements 
IgniteFsRecordResolv
 
     /** {@inheritDoc} */
     @Override public IgniteFsFileRange resolveRecords(IgniteFs ggfs, 
IgniteFsInputStream stream,
-        IgniteFsFileRange suggestedRecord) throws IgniteCheckedException, 
IOException {
+        IgniteFsFileRange suggestedRecord) throws IgniteException, IOException 
{
         long suggestedStart = suggestedRecord.start();
         long suggestedEnd = suggestedStart + suggestedRecord.length();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
index a1639d0..3d3f133 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/records/IgniteFsFixedLengthRecordResolver.java
@@ -47,7 +47,7 @@ public class IgniteFsFixedLengthRecordResolver implements 
IgniteFsRecordResolver
     /** {@inheritDoc} */
     @Override public IgniteFsFileRange resolveRecords(IgniteFs ggfs, 
IgniteFsInputStream stream,
         IgniteFsFileRange suggestedRecord)
-        throws IgniteCheckedException, IOException {
+        throws IgniteException, IOException {
         long suggestedEnd = suggestedRecord.start() + suggestedRecord.length();
 
         long startRem = suggestedRecord.start() % recLen;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
index fe55b87..7188085 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
@@ -62,9 +62,9 @@ public class IgniteAsyncSupportAdapter implements 
IgniteAsyncSupport {
      * @param fut Future.
      * @return If async mode is enabled saves future and returns {@code null},
      *         otherwise waits for future and returns result.
-     * @throws IgniteCheckedException If asynchronous mode is disabled and 
future failed.
+     * @throws IgniteException If asynchronous mode is disabled and future 
failed.
      */
-    public <R> R saveOrGet(IgniteFuture<R> fut) throws IgniteCheckedException {
+    public <R> R saveOrGet(IgniteFuture<R> fut) throws IgniteException {
         if (curFut != null) {
             curFut.set(fut);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
index f478377..ec341cf 100644
--- a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFuture.java
@@ -27,11 +27,11 @@ public interface IgniteFuture<R> {
      * returns computation result.
      *
      * @return Computation result.
-     * @throws org.gridgain.grid.GridInterruptedException Subclass of {@link 
IgniteCheckedException} thrown if the wait was interrupted.
-     * @throws IgniteFutureCancelledException Subclass of {@link 
IgniteCheckedException} throws if computation was cancelled.
-     * @throws IgniteCheckedException If computation failed.
+     * @throws org.gridgain.grid.GridInterruptedException Subclass of {@link 
IgniteException} thrown if the wait was interrupted.
+     * @throws IgniteFutureCancelledException Subclass of {@link 
IgniteException} throws if computation was cancelled.
+     * @throws IgniteException If computation failed.
      */
-    public R get() throws IgniteCheckedException;
+    public R get() throws IgniteException;
 
     /**
      * Synchronously waits for completion of the computation for
@@ -40,12 +40,12 @@ public interface IgniteFuture<R> {
      *
      * @param timeout The maximum time to wait in milliseconds.
      * @return Computation result.
-     * @throws GridInterruptedException Subclass of {@link 
IgniteCheckedException} thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link 
IgniteCheckedException} thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link 
IgniteCheckedException} throws if computation was cancelled.
-     * @throws IgniteCheckedException If computation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteException} 
thrown if the wait was interrupted.
+     * @throws IgniteFutureTimeoutException Subclass of {@link 
IgniteException} thrown if the wait was timed out.
+     * @throws IgniteFutureCancelledException Subclass of {@link 
IgniteException} throws if computation was cancelled.
+     * @throws IgniteException If computation failed.
      */
-    public R get(long timeout) throws IgniteCheckedException;
+    public R get(long timeout) throws IgniteException;
 
     /**
      * Synchronously waits for completion of the computation for
@@ -54,20 +54,20 @@ public interface IgniteFuture<R> {
      * @param timeout The maximum time to wait.
      * @param unit The time unit of the {@code timeout} argument.
      * @return Computation result.
-     * @throws GridInterruptedException Subclass of {@link 
IgniteCheckedException} thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link 
IgniteCheckedException} thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link 
IgniteCheckedException} throws if computation was cancelled.
-     * @throws IgniteCheckedException If computation failed.
+     * @throws GridInterruptedException Subclass of {@link IgniteException} 
thrown if the wait was interrupted.
+     * @throws IgniteFutureTimeoutException Subclass of {@link 
IgniteException} thrown if the wait was timed out.
+     * @throws IgniteFutureCancelledException Subclass of {@link 
IgniteException} throws if computation was cancelled.
+     * @throws IgniteException If computation failed.
      */
-    public R get(long timeout, TimeUnit unit) throws IgniteCheckedException;
+    public R get(long timeout, TimeUnit unit) throws IgniteException;
 
     /**
      * Cancels this future.
      *
      * @return {@code True} if future was canceled (i.e. was not finished 
prior to this call).
      * @throws IgniteCheckedException If cancellation failed.
      */
-    public boolean cancel() throws IgniteCheckedException;
+    public boolean cancel() throws IgniteException;
 
     /**
      * Checks if computation is done.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
----------------------------------------------------------------------
@@ -54,20 +54,20 @@ public interface IgniteFuture<R> {
      * @return {@code True} if future was canceled (i.e. was not finished 
prior to this call).
-     * @throws IgniteCheckedException If cancellation failed.
+     * @throws IgniteException If cancellation failed.
      */
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
index 692c725..86bdc72 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureCancelledException.java
@@ -15,7 +15,7 @@ import org.jetbrains.annotations.*;
 /**
  * Future computation cannot be retrieved because it was cancelled.
  */
-public class IgniteFutureCancelledException extends IgniteCheckedException {
+public class IgniteFutureCancelledException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
index 68d3d53..815a319 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteFutureTimeoutException.java
@@ -15,7 +15,7 @@ import org.jetbrains.annotations.*;
 /**
  * Future computation completion is timed out.
  */
-public class IgniteFutureTimeoutException extends IgniteCheckedException {
+public class IgniteFutureTimeoutException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java 
b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
index beb617d..5333bf3 100644
--- a/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
+++ b/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleAware.java
@@ -20,14 +20,14 @@ public interface LifecycleAware {
     /**
      * Starts grid component, called on grid start.
      *
      * @throws IgniteCheckedException If failed.
      */
-    public void start() throws IgniteCheckedException;
+    public void start() throws IgniteException;
 
     /**
      * Stops grid component, called on grid shutdown.
      *
      * @throws IgniteCheckedException If failed.
      */
-    public void stop() throws IgniteCheckedException;
+    public void stop() throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/lifecycle/LifecycleBean.java
----------------------------------------------------------------------
@@ -20,14 +20,14 @@ public interface LifecycleAware {
      * Starts grid component, called on grid start.
      *
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
@@ -20,14 +20,14 @@ public interface LifecycleAware {
      * Stops grid component, called on grid shutdown.
      *
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
index d535152..51958d2 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/authentication/AuthenticationAclProvider.java
@@ -27,7 +27,7 @@ public interface AuthenticationAclProvider {
      * Gets per-user access control map.
      *
      * @return Per-user access control map.
-     * @throws IgniteCheckedException If failed.
+     * @throws IgniteException If failed.
      */
-    public Map<GridSecurityCredentials, GridSecurityPermissionSet> acl() 
throws IgniteCheckedException;
+    public Map<GridSecurityCredentials, GridSecurityPermissionSet> acl() 
throws IgniteException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
index f819321..7b91f21 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/checkpoint/sharedfs/SharedFsUtils.java
@@ -35,12 +35,12 @@ final class SharedFsUtils {
      * @param m Grid marshaller.
      * @param log Messages logger.
      * @return Checkpoint data object read from given file.
-     * @throws IgniteCheckedException Thrown if data could not be converted
+     * @throws IgniteException Thrown if data could not be converted
      *    to {@link SharedFsCheckpointData} object.
      * @throws IOException Thrown if file read error occurred.
      */
     static SharedFsCheckpointData read(File file, IgniteMarshaller m, 
IgniteLogger log)
-        throws IOException, IgniteCheckedException {
+        throws IOException, IgniteException {
         assert file != null;
         assert m != null;
         assert log != null;
@@ -63,11 +63,11 @@ final class SharedFsUtils {
      * @param data Checkpoint data.
      * @param m Grid marshaller.
      * @param log Messages logger.
-     * @throws IgniteCheckedException Thrown if data could not be marshalled.
+     * @throws IgniteException Thrown if data could not be marshalled.
      * @throws IOException Thrown if file write operation failed.
      */
     static void write(File file, SharedFsCheckpointData data, IgniteMarshaller 
m, IgniteLogger log)
-        throws IOException, IgniteCheckedException {
+        throws IOException, IgniteException {
         assert file != null;
         assert m != null;
         assert data != null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
index 3d3368e..1d8e823 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/DiscoverySpiNodeAuthenticator.java
@@ -24,10 +24,10 @@ public interface DiscoverySpiNodeAuthenticator {
      * @param node Node to authenticate.
      * @param cred Security credentials.
      * @return Security context if authentication succeeded or {@code null} if 
authentication failed.
-     * @throws IgniteCheckedException If authentication process failed
+     * @throws IgniteException If authentication process failed
      *      (invalid credentials should not lead to this exception).
      */
-    public GridSecurityContext authenticateNode(ClusterNode node, 
GridSecurityCredentials cred) throws IgniteCheckedException;
+    public GridSecurityContext authenticateNode(ClusterNode node, 
GridSecurityCredentials cred) throws IgniteException;
 
     /**
      * Gets global node authentication flag.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
index 35aec0e..383d600 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpi.java
@@ -706,7 +706,7 @@ public class TcpDiscoverySpi extends TcpDiscoverySpiAdapter 
implements TcpDiscov
             if (extAddrs != null)
                 locNodeAttrs.put(createSpiAttributeName(ATTR_EXT_ADDRS), 
extAddrs);
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             throw new IgniteSpiException("Failed to resolve local host to 
addresses: " + locHost, e);
         }
 
@@ -1270,7 +1270,7 @@ public class TcpDiscoverySpi extends 
TcpDiscoverySpiAdapter implements TcpDiscov
 
                     locNode.setAttributes(attrs);
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     throw new IgniteSpiException("Failed to authenticate local 
node (will shutdown local node).", e);
                 }
 
@@ -1655,7 +1655,7 @@ public class TcpDiscoverySpi extends 
TcpDiscoverySpiAdapter implements TcpDiscov
 
             node.setAttributes(attrs);
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             throw new IgniteSpiException("Failed to marshal node security 
credentials: " + node.id(), e);
         }
     }
@@ -1676,7 +1676,7 @@ public class TcpDiscoverySpi extends 
TcpDiscoverySpiAdapter implements TcpDiscov
 
             return marsh.unmarshal(credBytes, null);
         }
-        catch (IgniteCheckedException e) {
+        catch (IgniteException e) {
             throw new IgniteSpiException("Failed to unmarshal node security 
credentials: " + node.id(), e);
         }
     }
@@ -3132,7 +3132,7 @@ public class TcpDiscoverySpi extends 
TcpDiscoverySpiAdapter implements TcpDiscov
                         node.setAttributes(attrs);
                     }
                 }
-                catch (IgniteCheckedException e) {
+                catch (IgniteException e) {
                     LT.error(log, e, "Authentication failed [nodeId=" + 
node.id() + ", addrs=" +
                         U.addressesAsString(node) + ']');
 
@@ -3583,7 +3583,7 @@ public class TcpDiscoverySpi extends 
TcpDiscoverySpiAdapter implements TcpDiscov
                                 authFailed = false;
                         }
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         U.error(log, "Failed to verify node permissions 
consistency (will drop the node): " + node, e);
                     }
                     finally {
@@ -4868,7 +4868,7 @@ public class TcpDiscoverySpi extends 
TcpDiscoverySpiAdapter implements TcpDiscov
                         if (!client)
                             writeToSocket(sock, RES_OK);
                     }
-                    catch (IgniteCheckedException e) {
+                    catch (IgniteException e) {
                         if (log.isDebugEnabled())
                             U.error(log, "Caught exception on message read 
[sock=" + sock +
                                 ", locNodeId=" + locNodeId + ", rmtNodeId=" + 
nodeId + ']', e);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/8bc850c2/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
index fa45f64..1d255d2 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/spi/discovery/tcp/TcpDiscoverySpiAdapter.java
@@ -16,11 +16,11 @@ import org.apache.ignite.marshaller.jdk.*;
 import org.apache.ignite.product.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.discovery.*;
 import org.apache.ignite.spi.discovery.tcp.internal.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
 import org.apache.ignite.spi.discovery.tcp.messages.*;
+import org.gridgain.grid.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.io.*;
 import org.gridgain.grid.util.typedef.*;
@@ -536,7 +536,7 @@ abstract class TcpDiscoverySpiAdapter extends 
IgniteSpiAdapter implements Discov
 
             return marsh.unmarshal(in == null ? sock.getInputStream() : in, 
U.gridClassLoader());
         }
-        catch (IOException | IgniteCheckedException e) {
+        catch (IOException | IgniteException e) {
             if (X.hasCause(e, SocketTimeoutException.class))
                 LT.warn(log, null, "Timed out waiting for message to be read 
(most probably, the reason is " +
                     "in long GC pauses on remote node. Current timeout: " + 
timeout + '.');

Reply via email to